﻿// (c) 2013 Cesys GmbH
// Author: Thomas Hoppe
using System;
using System.Collections.Generic;
using System.Text;

namespace CeboMsrNet
{
    /// <summary>
    /// Class to use when setting multiple outputs simultaneous. Direct construction is prohibited,
    /// as the count of the the various elements varies from device type to device type. Instances
    /// must be generated calling Device.CreateOutputFrame().
    /// </summary>
    public sealed class OutputFrame
    {
        private float[] _vvalues;
        private int[] _values;

        internal float[] VValues { get { return _vvalues; } }
        internal int[] Values { get { return _values; } }

        internal OutputFrame(int vcount, int count)
        {
            _vvalues = new float[vcount];
            _values = new int[count];
        }

        /// <summary>
        /// Define value that should be set on the specified digital port.
        /// </summary>
        /// <param name="index">Zero based index of port to specify.</param>
        /// <param name="value">Value to set at this port.</param>
        public void SetDigitalPort(int index, int value)
        {
            _values[index] = value;
        }

        /// <summary>
        /// Define value that should be set on the specified analog output.
        /// </summary>
        /// <param name="index">Zero based index of output to specify.</param>
        /// <param name="value">Value to set at this output.</param>
        public void SetAnalogOutput(int index, float value)
        {
            _vvalues[index] = value;
        }

        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("OutputFrame: \n");
            for (int i = 0; i < _vvalues.Length; ++i)
                sb.Append(string.Format("AnalogOutput #{0} = {1:0.00} V\n", i, _vvalues[i]));
            for (int i = 0; i < _values.Length; ++i)
                sb.Append(string.Format("DigitalPort #{0} = {1} (0x{1:x8})\n", i, _values[i]));
            return sb.ToString();
        }
    }
}
