package com.cesys.cebo.cebomsr;

/**
 * These objects are used to set the range of analog inputs and outputs.
 * Direct construction is not possible, getSupportedRanges() of {@link AnalogInput} and
 * {@link AnalogOutput} can be used to request the possible ranges of an input or output.
 *
 * @author Thomas Hoppe
 */
public final class Range {
	private final int _interfaceId;
	private final float _minValue, _maxValue;
	private final int _defaultInterChannelDelay;

	int getInterfaceId() {
		return _interfaceId;
	}

	int getDefaultInterChannelDelay() {
		return _defaultInterChannelDelay;
	}

	Range(int interfaceId, float minValue, float maxValue, int defaultInterChannelDelay) {
		_interfaceId = interfaceId;
		_minValue = minValue;
		_maxValue = maxValue;
		_defaultInterChannelDelay = defaultInterChannelDelay;
	}

	/**
	 * Return lower voltage.
	 */
	public float getMinValue() {
		return _minValue;
	}

	/**
	 * Return upper voltage.
	 */
	public float getMaxValue() {
		return _maxValue;
	}

	@Override
	public String toString() {
		return "Range: " + _minValue + "V - " + _maxValue + "V";
	}
}
